#!/bin/sh
##############################################################
# glucopy-raid.sh
#
# Creates the /glucopy directory
# Copies partition information in sys_partitions.txt
# Optionally makes a copy of the MBR in mbr.bin
# Copies working GNU/Linux system to .tgz files
#
# USAGE:
# Boot system with a rescue CD or any bootable CD
# that supports your type of disks (SATA/SCSI or IDE).
# run the back-up script: ./glucopy.sh
# 
# In this example the system is on /dev/sda
# /dev/sda1 has boot (/boot) -> mounted to /mnt1
# /dev/sda2 (/dev/md2) has system root (/) -> mounted to /mnt2
# /dev/sda3 has home (/home) and space 
# to hold the information to be copied -> mounted to /mnt3
# /dev/sda4 is a spare partition
# /dev/sdb1 is a copy of /boot
# /dev/sdb2 participates in /dev/md2
# /dev/sdb3 participates in /dev/md3
# /dev/sdb4 is a spare partition
# 061116 jp/dm
# 070503 sg - root user and program availability checks
# 091217 dm - raid (md) volumes
#
# Multiple-device volumes must be started before the script is run
# in single-user mode or after booting with a live CD:
#
# init 1
# mdadm --auto=yes /dev/md2 /dev/sd[ab]2
# mdadm --auto=yes /dev/md3 /dev/sd[ab]3
##############################################################
# Change the following to reflect the place where your system root (/) 
# and the home directories (/home/*) are mounted

# Check that user is root
USER=`id -un`
if (test $USER != "root");then
        echo "Error: This script must be executed by root"
        exit
fi

# Check availability of programs
TAR=`which tar 2>/dev/null`
if (test -z "$TAR");then
        echo "Error: The \"tar\" program was not found"
        echo "       The live CD you are using does not contain the program \"tar\"."
        echo "       The backup procedure cannot be executed without it."
  echo "       Please use another live CD."
  exit
fi

# The sfdisk program may be available on your boot medium and/or
# your boot disk.  In the latter case, make sure that the sfdisk 
# program is compatible with the boot system.
#
SFDISK=`which sfdisk 2>/dev/null`
#SFDISK=`pwd`\/sfdisk  2>/dev/null

if (test -z "$SFDISK");then
        echo "Error: The \"sfdisk\" program was not found"
        echo "       The live CD you are using does not contain the program \"sfdisk\"."
        echo "       The backup procedure cannot be executed without it."
        echo "       Please use another live CD."
        exit
fi

# The mdadm program may be available on your boot medium and/or
# your boot disk.  In the latter case, make sure that the mdadm 
# program is compatible with the boot system.
#
#MDADM=`which mdadm 2>/dev/null`
MDADM=`pwd`\/mdadm

if (test -z "$MDADM");then
        echo "Error: The \"mdadm\" program was not found"
        echo "       The live CD you are using does not contain the program \"mdadm\"."
        echo "       The backup procedure cannot be executed without it."
        echo "       Please use another live CD."
        exit
fi

# Checkpoint - use the exit command to check parts of your script
#exit

mkdir /tmp/mnt1
mkdir /tmp/mnt2
mkdir /tmp/mnt3
mount /dev/sda1 /tmp/mnt1
mount /dev/md2 /tmp/mnt2
mount /dev/md3 /tmp/mnt3

# The directory to hold the system copy is placed on the larger (home) partition
mkdir /tmp/mnt3/glucopy

# Change to the working directory
cd /tmp/mnt3/glucopy

# Optionally copy MBR information
#dd if=/dev/sda of=mbr.bin bs=512 count=1
# Copy partition information
"$SFDISK" -d /dev/sda > sfdisk.sda
"$SFDISK" -d /dev/sdb > sfdisk.sdb

# Make tarballs
"$TAR" -C /tmp/mnt1 -cpvzf bootcopy.tgz `find .`
"$TAR" -C /tmp/mnt2 -cpvzf syscopy.tgz bin etc lib media opt root sbin usr var dev

# Move up a level
cd ..
# here we are under the /home directory level
# notice that --exclude will exclude anything that matches a _pattern_
# the glucopy directory will still be created in the tarball
"$TAR" --exclude=glucopy/* -cpvzf ./glucopy/homecopy.tgz *

# Copy the backup/restore scripts (in the present working directory), and the sfdisk program
cp `pwd`/* ./glucopy
cp "$SFDISK" ./glucopy
cp "$MDADM" ./glucopy

# Notify user
echo glucopy: finished
